@@ -14,6 +14,7 @@ project_settings = DefaultTestSettings(
     APP_NAME=app_name,
     ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
     SUBJECT_VISIT_MODEL="visit_schedule_app.subjectvisit",
+    SUBJECT_VISIT_MISSED_MODEL="visit_schedule_app.subjectvisitmissed",
     INSTALLED_APPS=[
         "django.contrib.admin",
         "django.contrib.auth",
@@ -32,6 +33,7 @@ project_settings = DefaultTestSettings(
         "edc_export.apps.AppConfig",
         "edc_facility.apps.AppConfig",
         "edc_identifier.apps.AppConfig",
+        "edc_list_data.apps.AppConfig",
         "edc_metadata.apps.AppConfig",
         "edc_notification.apps.AppConfig",
         "edc_protocol.apps.AppConfig",
